Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorBrian Vosburgh2013-03-14 17:52:12 +0000
committerBrian Vosburgh2013-03-26 15:22:36 +0000
commit1411e33fa4b068c85780ebc1fb46f8ff4de4d377 (patch)
tree1748c69ac8972906bed3eb955e9da7520efbfadb /common/plugins/org.eclipse.jpt.common.core/src
parenta2b23c5741fd8090308ddeca43de59c9e46db921 (diff)
downloadwebtools.dali-1411e33fa4b068c85780ebc1fb46f8ff4de4d377.tar.gz
webtools.dali-1411e33fa4b068c85780ebc1fb46f8ff4de4d377.tar.xz
webtools.dali-1411e33fa4b068c85780ebc1fb46f8ff4de4d377.zip
rename SingleUseQueueingCommandExecutor to
SingleUseQueueingCommandContext
Diffstat (limited to 'common/plugins/org.eclipse.jpt.common.core/src')
-rw-r--r--common/plugins/org.eclipse.jpt.common.core/src/org/eclipse/jpt/common/core/internal/utility/command/SingleUseQueueingJobCommandContext.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/common/plugins/org.eclipse.jpt.common.core/src/org/eclipse/jpt/common/core/internal/utility/command/SingleUseQueueingJobCommandContext.java b/common/plugins/org.eclipse.jpt.common.core/src/org/eclipse/jpt/common/core/internal/utility/command/SingleUseQueueingJobCommandContext.java
index c4adb54b2e..8ddc417585 100644
--- a/common/plugins/org.eclipse.jpt.common.core/src/org/eclipse/jpt/common/core/internal/utility/command/SingleUseQueueingJobCommandContext.java
+++ b/common/plugins/org.eclipse.jpt.common.core/src/org/eclipse/jpt/common/core/internal/utility/command/SingleUseQueueingJobCommandContext.java
@@ -12,28 +12,28 @@ package org.eclipse.jpt.common.core.internal.utility.command;
import org.eclipse.jpt.common.core.utility.command.JobCommand;
import org.eclipse.jpt.common.utility.command.CommandContext;
import org.eclipse.jpt.common.utility.command.StatefulCommandContext;
-import org.eclipse.jpt.common.utility.internal.command.SingleUseQueueingCommandExecutor;
+import org.eclipse.jpt.common.utility.internal.command.SingleUseQueueingCommandContext;
/**
* This command context wraps and extends a {@link SingleUseQueueingCommandExecutor},
* adding support for executing {@link JobCommand}s.
*/
public class SingleUseQueueingJobCommandContext
- extends AbstractSingleUseQueueingJobCommandContext<SingleUseQueueingCommandExecutor, StatefulCommandContext>
+ extends AbstractSingleUseQueueingJobCommandContext<SingleUseQueueingCommandContext, StatefulCommandContext>
{
public SingleUseQueueingJobCommandContext() {
- this(new SingleUseQueueingCommandExecutor());
+ this(new SingleUseQueueingCommandContext());
}
public SingleUseQueueingJobCommandContext(CommandContext commandExecutor) {
- this(new SingleUseQueueingCommandExecutor(commandExecutor));
+ this(new SingleUseQueueingCommandContext(commandExecutor));
}
public SingleUseQueueingJobCommandContext(StatefulCommandContext commandExecutor) {
- this(new SingleUseQueueingCommandExecutor(commandExecutor));
+ this(new SingleUseQueueingCommandContext(commandExecutor));
}
- public SingleUseQueueingJobCommandContext(SingleUseQueueingCommandExecutor commandExecutor) {
+ public SingleUseQueueingJobCommandContext(SingleUseQueueingCommandContext commandExecutor) {
super(commandExecutor);
}
}
@@ -12,28 +12,28 @@ package org.eclipse.jpt.common.core.internal.utility.command;
/**
- * This command context wraps and extends a {@link SingleUseQueueingCommandExecutor},
+ * This command context wraps and extends a {@link SingleUseQueueingCommandContext},
* adding support for executing {@link JobCommand}s.
*/

Back to the top